@@ -35,6 +35,8 @@ __all__ = (
     "DeploymentJobTypeDef",
     "DeploymentLaunchConfigTypeDef",
     "FailedCreateSimulationJobRequestTypeDef",
+    "FailureSummaryTypeDef",
+    "FinishedWorldsSummaryTypeDef",
     "FleetTypeDef",
     "LaunchConfigTypeDef",
     "LoggingConfigTypeDef",
@@ -59,8 +61,16 @@ __all__ = (
     "SimulationJobTypeDef",
     "SimulationSoftwareSuiteTypeDef",
     "SourceTypeDef",
+    "TemplateSummaryTypeDef",
     "VPCConfigResponseTypeDef",
     "VPCConfigTypeDef",
+    "WorldConfigTypeDef",
+    "WorldCountTypeDef",
+    "WorldExportJobSummaryTypeDef",
+    "WorldFailureTypeDef",
+    "WorldGenerationJobSummaryTypeDef",
+    "WorldSummaryTypeDef",
+    "BatchDeleteWorldsResponseTypeDef",
     "BatchDescribeSimulationJobResponseTypeDef",
     "CreateDeploymentJobResponseTypeDef",
     "CreateFleetResponseTypeDef",
@@ -70,6 +80,9 @@ __all__ = (
     "CreateSimulationApplicationResponseTypeDef",
     "CreateSimulationApplicationVersionResponseTypeDef",
     "CreateSimulationJobResponseTypeDef",
+    "CreateWorldExportJobResponseTypeDef",
+    "CreateWorldGenerationJobResponseTypeDef",
+    "CreateWorldTemplateResponseTypeDef",
     "DeregisterRobotResponseTypeDef",
     "DescribeDeploymentJobResponseTypeDef",
     "DescribeFleetResponseTypeDef",
@@ -78,7 +91,12 @@ __all__ = (
     "DescribeSimulationApplicationResponseTypeDef",
     "DescribeSimulationJobBatchResponseTypeDef",
     "DescribeSimulationJobResponseTypeDef",
+    "DescribeWorldExportJobResponseTypeDef",
+    "DescribeWorldGenerationJobResponseTypeDef",
+    "DescribeWorldResponseTypeDef",
+    "DescribeWorldTemplateResponseTypeDef",
     "FilterTypeDef",
+    "GetWorldTemplateBodyResponseTypeDef",
     "ListDeploymentJobsResponseTypeDef",
     "ListFleetsResponseTypeDef",
     "ListRobotApplicationsResponseTypeDef",
@@ -87,13 +105,19 @@ __all__ = (
     "ListSimulationJobBatchesResponseTypeDef",
     "ListSimulationJobsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "ListWorldExportJobsResponseTypeDef",
+    "ListWorldGenerationJobsResponseTypeDef",
+    "ListWorldTemplatesResponseTypeDef",
+    "ListWorldsResponseTypeDef",
     "PaginatorConfigTypeDef",
     "RegisterRobotResponseTypeDef",
     "SourceConfigTypeDef",
     "StartSimulationJobBatchResponseTypeDef",
     "SyncDeploymentJobResponseTypeDef",
+    "TemplateLocationTypeDef",
     "UpdateRobotApplicationResponseTypeDef",
     "UpdateSimulationApplicationResponseTypeDef",
+    "UpdateWorldTemplateResponseTypeDef",
 )
 
 BatchPolicyTypeDef = TypedDict(
@@ -227,6 +251,18 @@ FailedCreateSimulationJobRequestTypeDef = TypedDict(
     total=False,
 )
 
+FailureSummaryTypeDef = TypedDict(
+    "FailureSummaryTypeDef",
+    {"totalFailureCount": int, "failures": List["WorldFailureTypeDef"]},
+    total=False,
+)
+
+FinishedWorldsSummaryTypeDef = TypedDict(
+    "FinishedWorldsSummaryTypeDef",
+    {"finishedCount": int, "succeededWorlds": List[str], "failureSummary": "FailureSummaryTypeDef"},
+    total=False,
+)
+
 FleetTypeDef = TypedDict(
     "FleetTypeDef",
     {
@@ -426,7 +462,9 @@ _RequiredSimulationApplicationConfigTypeDef = TypedDict(
     {"application": str, "launchConfig": "LaunchConfigTypeDef"},
 )
 _OptionalSimulationApplicationConfigTypeDef = TypedDict(
-    "_OptionalSimulationApplicationConfigTypeDef", {"applicationVersion": str}, total=False
+    "_OptionalSimulationApplicationConfigTypeDef",
+    {"applicationVersion": str, "worldConfigs": List["WorldConfigTypeDef"]},
+    total=False,
 )
 
 
@@ -610,6 +648,12 @@ SourceTypeDef = TypedDict(
     total=False,
 )
 
+TemplateSummaryTypeDef = TypedDict(
+    "TemplateSummaryTypeDef",
+    {"arn": str, "createdAt": datetime, "lastUpdatedAt": datetime, "name": str},
+    total=False,
+)
+
 VPCConfigResponseTypeDef = TypedDict(
     "VPCConfigResponseTypeDef",
     {"subnets": List[str], "securityGroups": List[str], "vpcId": str, "assignPublicIp": bool},
@@ -626,6 +670,66 @@ class VPCConfigTypeDef(_RequiredVPCConfigTypeDef, _OptionalVPCConfigTypeDef):
     pass
 
 
+WorldConfigTypeDef = TypedDict("WorldConfigTypeDef", {"world": str}, total=False)
+
+WorldCountTypeDef = TypedDict(
+    "WorldCountTypeDef", {"floorplanCount": int, "interiorCountPerFloorplan": int}, total=False
+)
+
+WorldExportJobSummaryTypeDef = TypedDict(
+    "WorldExportJobSummaryTypeDef",
+    {
+        "arn": str,
+        "status": Literal["Pending", "Running", "Completed", "Failed", "Canceling", "Canceled"],
+        "createdAt": datetime,
+        "worlds": List[str],
+    },
+    total=False,
+)
+
+WorldFailureTypeDef = TypedDict(
+    "WorldFailureTypeDef",
+    {
+        "failureCode": Literal[
+            "InternalServiceError",
+            "LimitExceeded",
+            "ResourceNotFound",
+            "RequestThrottled",
+            "InvalidInput",
+            "AllWorldGenerationFailed",
+        ],
+        "sampleFailureReason": str,
+        "failureCount": int,
+    },
+    total=False,
+)
+
+WorldGenerationJobSummaryTypeDef = TypedDict(
+    "WorldGenerationJobSummaryTypeDef",
+    {
+        "arn": str,
+        "template": str,
+        "createdAt": datetime,
+        "status": Literal[
+            "Pending", "Running", "Completed", "Failed", "PartialFailed", "Canceling", "Canceled"
+        ],
+        "worldCount": "WorldCountTypeDef",
+        "succeededWorldCount": int,
+        "failedWorldCount": int,
+    },
+    total=False,
+)
+
+WorldSummaryTypeDef = TypedDict(
+    "WorldSummaryTypeDef",
+    {"arn": str, "createdAt": datetime, "generationJob": str, "template": str},
+    total=False,
+)
+
+BatchDeleteWorldsResponseTypeDef = TypedDict(
+    "BatchDeleteWorldsResponseTypeDef", {"unprocessedWorlds": List[str]}, total=False
+)
+
 BatchDescribeSimulationJobResponseTypeDef = TypedDict(
     "BatchDescribeSimulationJobResponseTypeDef",
     {"jobs": List["SimulationJobTypeDef"], "unprocessedJobs": List[str]},
@@ -814,6 +918,64 @@ CreateSimulationJobResponseTypeDef = TypedDict(
     total=False,
 )
 
+CreateWorldExportJobResponseTypeDef = TypedDict(
+    "CreateWorldExportJobResponseTypeDef",
+    {
+        "arn": str,
+        "status": Literal["Pending", "Running", "Completed", "Failed", "Canceling", "Canceled"],
+        "createdAt": datetime,
+        "failureCode": Literal[
+            "InternalServiceError",
+            "LimitExceeded",
+            "ResourceNotFound",
+            "RequestThrottled",
+            "InvalidInput",
+            "AccessDenied",
+        ],
+        "clientRequestToken": str,
+        "outputLocation": "OutputLocationTypeDef",
+        "iamRole": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+CreateWorldGenerationJobResponseTypeDef = TypedDict(
+    "CreateWorldGenerationJobResponseTypeDef",
+    {
+        "arn": str,
+        "status": Literal[
+            "Pending", "Running", "Completed", "Failed", "PartialFailed", "Canceling", "Canceled"
+        ],
+        "createdAt": datetime,
+        "failureCode": Literal[
+            "InternalServiceError",
+            "LimitExceeded",
+            "ResourceNotFound",
+            "RequestThrottled",
+            "InvalidInput",
+            "AllWorldGenerationFailed",
+        ],
+        "clientRequestToken": str,
+        "template": str,
+        "worldCount": "WorldCountTypeDef",
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+CreateWorldTemplateResponseTypeDef = TypedDict(
+    "CreateWorldTemplateResponseTypeDef",
+    {
+        "arn": str,
+        "clientRequestToken": str,
+        "createdAt": datetime,
+        "name": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
 DeregisterRobotResponseTypeDef = TypedDict(
     "DeregisterRobotResponseTypeDef", {"fleet": str, "robot": str}, total=False
 )
@@ -1026,8 +1188,87 @@ DescribeSimulationJobResponseTypeDef = TypedDict(
     total=False,
 )
 
+DescribeWorldExportJobResponseTypeDef = TypedDict(
+    "DescribeWorldExportJobResponseTypeDef",
+    {
+        "arn": str,
+        "status": Literal["Pending", "Running", "Completed", "Failed", "Canceling", "Canceled"],
+        "createdAt": datetime,
+        "failureCode": Literal[
+            "InternalServiceError",
+            "LimitExceeded",
+            "ResourceNotFound",
+            "RequestThrottled",
+            "InvalidInput",
+            "AccessDenied",
+        ],
+        "failureReason": str,
+        "clientRequestToken": str,
+        "worlds": List[str],
+        "outputLocation": "OutputLocationTypeDef",
+        "iamRole": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+DescribeWorldGenerationJobResponseTypeDef = TypedDict(
+    "DescribeWorldGenerationJobResponseTypeDef",
+    {
+        "arn": str,
+        "status": Literal[
+            "Pending", "Running", "Completed", "Failed", "PartialFailed", "Canceling", "Canceled"
+        ],
+        "createdAt": datetime,
+        "failureCode": Literal[
+            "InternalServiceError",
+            "LimitExceeded",
+            "ResourceNotFound",
+            "RequestThrottled",
+            "InvalidInput",
+            "AllWorldGenerationFailed",
+        ],
+        "failureReason": str,
+        "clientRequestToken": str,
+        "template": str,
+        "worldCount": "WorldCountTypeDef",
+        "finishedWorldsSummary": "FinishedWorldsSummaryTypeDef",
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+DescribeWorldResponseTypeDef = TypedDict(
+    "DescribeWorldResponseTypeDef",
+    {
+        "arn": str,
+        "generationJob": str,
+        "template": str,
+        "createdAt": datetime,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+DescribeWorldTemplateResponseTypeDef = TypedDict(
+    "DescribeWorldTemplateResponseTypeDef",
+    {
+        "arn": str,
+        "clientRequestToken": str,
+        "name": str,
+        "createdAt": datetime,
+        "lastUpdatedAt": datetime,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
 FilterTypeDef = TypedDict("FilterTypeDef", {"name": str, "values": List[str]}, total=False)
 
+GetWorldTemplateBodyResponseTypeDef = TypedDict(
+    "GetWorldTemplateBodyResponseTypeDef", {"templateBody": str}, total=False
+)
+
 ListDeploymentJobsResponseTypeDef = TypedDict(
     "ListDeploymentJobsResponseTypeDef",
     {"deploymentJobs": List["DeploymentJobTypeDef"], "nextToken": str},
@@ -1084,6 +1325,48 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef", {"tags": Dict[str, str]}, total=False
 )
 
+_RequiredListWorldExportJobsResponseTypeDef = TypedDict(
+    "_RequiredListWorldExportJobsResponseTypeDef",
+    {"worldExportJobSummaries": List["WorldExportJobSummaryTypeDef"]},
+)
+_OptionalListWorldExportJobsResponseTypeDef = TypedDict(
+    "_OptionalListWorldExportJobsResponseTypeDef", {"nextToken": str}, total=False
+)
+
+
+class ListWorldExportJobsResponseTypeDef(
+    _RequiredListWorldExportJobsResponseTypeDef, _OptionalListWorldExportJobsResponseTypeDef
+):
+    pass
+
+
+_RequiredListWorldGenerationJobsResponseTypeDef = TypedDict(
+    "_RequiredListWorldGenerationJobsResponseTypeDef",
+    {"worldGenerationJobSummaries": List["WorldGenerationJobSummaryTypeDef"]},
+)
+_OptionalListWorldGenerationJobsResponseTypeDef = TypedDict(
+    "_OptionalListWorldGenerationJobsResponseTypeDef", {"nextToken": str}, total=False
+)
+
+
+class ListWorldGenerationJobsResponseTypeDef(
+    _RequiredListWorldGenerationJobsResponseTypeDef, _OptionalListWorldGenerationJobsResponseTypeDef
+):
+    pass
+
+
+ListWorldTemplatesResponseTypeDef = TypedDict(
+    "ListWorldTemplatesResponseTypeDef",
+    {"templateSummaries": List["TemplateSummaryTypeDef"], "nextToken": str},
+    total=False,
+)
+
+ListWorldsResponseTypeDef = TypedDict(
+    "ListWorldsResponseTypeDef",
+    {"worldSummaries": List["WorldSummaryTypeDef"], "nextToken": str},
+    total=False,
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
@@ -1162,6 +1445,8 @@ SyncDeploymentJobResponseTypeDef = TypedDict(
     total=False,
 )
 
+TemplateLocationTypeDef = TypedDict("TemplateLocationTypeDef", {"s3Bucket": str, "s3Key": str})
+
 UpdateRobotApplicationResponseTypeDef = TypedDict(
     "UpdateRobotApplicationResponseTypeDef",
     {
@@ -1191,3 +1476,9 @@ UpdateSimulationApplicationResponseTypeDef = TypedDict(
     },
     total=False,
 )
+
+UpdateWorldTemplateResponseTypeDef = TypedDict(
+    "UpdateWorldTemplateResponseTypeDef",
+    {"arn": str, "name": str, "createdAt": datetime, "lastUpdatedAt": datetime},
+    total=False,
+)
